/* main.c
 * Command line interface.
 *
 * This fixed point version of shine is based on Gabriel Bouvigne's original
 * source, version 0.1.2
 *
 * 09/02/01 PRE Ported to Acorn computers running RISC OS.
 * 19/06/03 PRE MPEG2/2.5 support added. RISC OS build conditional.
 */

#include "types.h"

int timelimit = 40;
int dsp_speed = 16000;
int dsp_stereo = 0;
int samplesize = 16;
int flag=0;

FILE * pFile;

/* write a WAVE-header */
void start_wave(int fd, unsigned long cnt)
{
  WaveHeader wh;

  wh.main_chunk = RIFF;
  wh.length     = cnt + sizeof(WaveHeader) - 8;
  wh.chunk_type = WAVE;
  wh.sub_chunk  = FMT;
  wh.sc_len     = 16;
  wh.format     = PCM_CODE;
  wh.modus      = dsp_stereo ? 2 : 1;
  printf("stereo 2 or mono 1: %d\n", wh.modus);
  wh.sample_fq  = dsp_speed;
  wh.byte_p_spl = ((samplesize == 8) ? 1 : 2) * (dsp_stereo ? 2 : 1);
  wh.byte_p_sec = dsp_speed * wh.modus * wh.byte_p_spl;
  wh.bit_p_spl  = samplesize;
  wh.data_chunk = DATA;
  wh.data_length= cnt;
  fwrite (&wh, sizeof(WaveHeader), 1, fd);
}

unsigned long calc_count(void)
{
  unsigned long count;

  if (!timelimit)
    count = 0x7fffffff;
  else {
    count = timelimit * dsp_speed;
    if (dsp_stereo)
      count *= 2;
    if (samplesize != 8)
      count *= 2;
  }
  return count;
}

void record(FILE* fd) 
{
	//WAVE header calls
		int i = 0;
		unsigned long cnt;
                cnt = calc_count();

                start_wave(fd, cnt);

  		short int * samples = (short *) malloc(sizeof(short) * numSamples);

		for (i=0; i<numSamples; i++) 
                {
			//volatile unsigned int audioIn = inw(na_audio);
			samples[i] = IORD(na_audio, 1);
			switch(i)
			{
                        case 8000:
			   printf("15 sec left\n");
			   break;
                        case 16000:
			   printf("14 sec left\n");
			   break;
			case 24000:
			   printf("13 sec left\n");
			   break;
			case 32000:
			   printf("12 sec left\n");
			   break;
			case 40000:
			   printf("11 sec left\n");
			   break;
			case 48000:
			   printf("10 sec left\n");
			   break;
			case 56000:
			   printf("9 sec left\n");
			   break;
			case 64000:
			   printf("8 sec left\n");
			   break;
			case 72000:
			   printf("7 sec left\n");
			   break;
			case 80000:
			   printf("6 sec left\n");
			   break;
			case 88000:
			   printf("5 sec left\n");
			   break;
			case 96000:
			   printf("4 sec left\n");
			   break;
			case 114000:
			   printf("3 sec left\n");
			   break;
			case 122000:
			   printf("2 sec left\n");
			   break;
			case 130000:
			   printf("1 sec left\n");
			   break;
			case 138000:
			   printf("0 sec left\n");
			   break;
                        //default:

                       }
		}

		int numSamplesWritten = fwrite(samples, sizeof(short), numSamples, fd);
		printf("numSamplesWritten=%d\n", numSamplesWritten);
		if (numSamplesWritten!=numSamples) {
		   printf("Error: only wrote %d of %d samples\n", numSamplesWritten, numSamples);
		}

                //printf("samples[128]=%d\n", samples[128]);
		//printf("samples[129]=%d\n", samples[129]);

		fflush(fd);
                free(samples);
                fclose(fd);
		flag = 1;


}


/*
 * main:
 * -----
 */
int main()
{
  static int j=0;
  static int i=0;




  printf("Program Starts!!");

  while(1)
  {

    if ((inw(na_switch_pio) == 0x3) && (flag==0))
    {
        char str1[20];
        char str2[20];
        //const char* saxiao = "/mnt/test";
        //const char* WAVE = "wav";
        const char* name = "/mnt/Mike";
        const char* EMPEE3 = "mp3";
       //for (i=0;i<10;i++){
       //strcpy(str1, saxiao);
       sprintf(str1, "/mnt/test_%d.wav", j);

        FILE * fd = fopen(str1, "w");
        if (fd==NULL)
        {
	 printf("Error opening file\n");
	 exit(-1);
        }

	printf("Start Recording......\n");
	record(fd);
	printf("Done recording!\n");
        //The ADC to wac code
        strcpy(str2, name);
        sprintf(str2, "%s_%d.%s", name, j, EMPEE3);
        j++;
        mp3encode(str2, str1);
        printf("Done Encoding %s\n",str2);
    }
    if ((inw(na_switch_pio) == 0x1) &&  (flag==1))
    {
      flag=0;
      printf("Ready to Record\n");
    }
    if ((inw(na_switch_pio) == 0x5)  && (flag==0))
       exit(EXIT_SUCCESS);
  }
}


